@@ -3,8 +3,8 @@
  *
  *   (C) 2004 Dominic Morris
  *
- *   $Id: menu.c,v 1.18 2004/04/22 18:36:24 dom Exp $
- *   $Date: 2004/04/22 18:36:24 $
+ *   $Id: menu.c,v 1.21 2005/04/01 11:49:04 dom Exp $
+ *   $Date: 2005/04/01 11:49:04 $
  *
  *
  *   Constructs a menu and all such things
@@ -442,6 +442,7 @@ static int menu_keys(void *ptr, int code)
 
     switch ( code ) {
     case keyChanUp:
+        menu_free_dialcode(menu);
         if ( streamtype != MEDIA_MPEG ) {
             if ( menu->current_selection > 0 ) {
                 menu->current_selection--;
@@ -459,6 +460,7 @@ static int menu_keys(void *ptr, int code)
         }
         break;
     case keyChanDn:
+        menu_free_dialcode(menu);
         if ( streamtype != MEDIA_MPEG ) {
             if ( menu->current_selection < menu->numoptions - 1 ) {
                 menu->current_selection++;
@@ -665,6 +667,28 @@ menu_t  *menu_child(menu_t *menu)
     return menu->child;
 }
 
+void    *menu_return_param(menu_t *menu)
+{
+    return menu->param;
+}
+
+void menu_set_entry(menu_t * menu, int entry) 
+{
+    menu->current_selection=entry;
+    if (entry < 0) 
+        menu->current_selection = 0;
+    if (entry >= menu->numoptions) 
+        menu->current_selection=menu->numoptions-1;
+    menu->top_offset = menu->current_selection;
+}
+
+
+
+int  menu_get_entry(menu_t * menu)
+{
+    return menu->current_selection;
+}
+
 
 
  
