@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: menuapp.c,v 1.52 2004/10/24 11:46:56 dom Exp $
- *   $Date: 2004/10/24 11:46:56 $
+ *   $Id: menuapp.c,v 1.54 2005/04/01 11:39:20 dom Exp $
+ *   $Date: 2005/04/01 11:39:20 $
  *
  *
  *   Implements the application
@@ -24,7 +24,7 @@
 #include <libxml/parser.h>
 #endif
 
-#ifdef HAVE_LIBJPEG
+#if HAVE_LIBJPEG | HAVE_MAGICK
 #include  "libmvpimage.h"
 #endif
 
@@ -52,6 +52,7 @@ struct _menuapp {
     surface_t *old_sfc;
 #ifdef VDR_PLUGIN
     int        Now;
+    int        current_position;
 #endif
     char      *current_media;
     int        num_next_media;
@@ -70,6 +71,7 @@ typedef struct {
     /* For handling scanning of directories */
     int         filelist_num;
     filelist_t *filelist;
+    int         currentsel;  /* Currently viewing file */
 } dirlist_t;
 
 
@@ -97,8 +99,9 @@ static int           menuapp_live_tv(menu_t *menu,void *imenuapp, int sel);
 static int           menuapp_live_radio(menu_t *menu,void *imenuapp, int sel);
 static int           menuapp_mpeg(menu_t *menu,void *imenuapp, int sel);
 static int           menuapp_music(menu_t *menu,void *imenuapp, int sel);
-#ifdef HAVE_LIBJPEG
+#if HAVE_LIBJPEG | HAVE_MAGICK
 static int           menuapp_pictures(menu_t *menu,void *imenuapp, int sel);
+static int           menuapp_display_image(dirlist_t *dirlist, int index, int rotate);
 #endif
 
 #ifdef HAVE_LIBXML2
@@ -234,7 +237,7 @@ static int menuapp_main(menu_t *menu,void *imenuapp, int sel)
     }
 
 
-#ifdef HAVE_LIBJPEG
+#if HAVE_LIBJPEG | HAVE_MAGICK
     if ( c_pictures_dir_num ) {
         menu_add(menuapp->menu,tr("Pictures"),menuapp_pictures);
     }
@@ -251,7 +254,7 @@ static int menuapp_main(menu_t *menu,void *imenuapp, int sel)
     menu_add(menuapp->menu,tr("Schedules"),schedule_menuapp);
     menu_add(menuapp->menu,tr("Internet Radio"),menuapp_live_radio);
     menu_add(menuapp->menu,tr("VDR Recordings"),menuapp_vdrrecs);
-#ifdef HAVE_LIBJPEG
+#if HAVE_LIBJPEG | HAVE_MAGICK
     menu_add(menuapp->menu,tr("Pictures"),menuapp_pictures);
 #endif
 #ifdef HAVE_LIBXML2
@@ -442,7 +445,7 @@ static int menuapp_music(menu_t *menu,void *imenuapp, int sel)
 /*
  *   Handle the root menu for Pictures menu
  */
-#ifdef HAVE_LIBJPEG
+#if HAVE_LIBJPEG | HAVE_MAGICK
 static int menuapp_pictures(menu_t *menu,void *imenuapp, int sel)
 {
 #ifdef VDR_PLUGIN
@@ -560,7 +563,7 @@ static int process_rss(menu_t *menu,void *imenuapp, int sel)
 
     cur = cur->xmlChildrenNode;
     while (cur != NULL) {
-        if( !xmlStrcasecmp(cur->name, (const xmlChar *) "channel")) {
+        if( xmlStrcasecmp(cur->name, (const xmlChar *) "channel") == 0 ) {
 
             dirlist2 = new_dirlist(dirlist->menuapp);
 	    
@@ -659,12 +662,13 @@ static int process_media(menu_t *menu,void *imenuapp, int sel)
     menu_set_dialcode_selection(menu,0);
 
     entry = &dirlist->filelist[sel];
+    dirlist->currentsel = sel;
 
     if ( entry->flags & FILE_URL ) {        
         /* It's a channel entry */
         if ( dirlist->menuapp->current_media ) {        
             free(dirlist->menuapp->current_media);
-	}
+        }
         dirlist->menuapp->current_media = strdup(entry->url);
         dirlist->menuapp->paused = FALSE;
         dongle_send_play(dirlist->menuapp->dongle,entry->url);
@@ -688,12 +692,12 @@ static int process_media(menu_t *menu,void *imenuapp, int sel)
         menu_set_param_clearup(child,delete_dirlist);
         menu_set_dialcode_callback(child, dial_entry);
             
-	has_subdirs = 0;
+        has_subdirs = 0;
         for ( i = 0; i < dirlist2->filelist_num; i++ ) {
             menu_add(child,dirlist2->filelist[i].display_name,process_media);             
-	    if (dirlist2->filelist[i].flags & FILE_DIR) {
-	    	has_subdirs = 1;
-	    }
+            if (dirlist2->filelist[i].flags & FILE_DIR) {
+                has_subdirs = 1;
+            }
         }
 
         blue_key = NULL;
@@ -761,30 +765,17 @@ static int process_media(menu_t *menu,void *imenuapp, int sel)
             }
 #if HAVE_MAGICK | HAVE_LIBJPEG
         } else if (  filetype & MEDIA_PICTURE ) {
-            surface_t  *surface;
-            int         w,d;
+            int         ret;
 
-            w = render_get_width(dirlist->menuapp->render);
-            d = render_get_depth(dirlist->menuapp->render);
-            snprintf(buf,sizeof(buf),"%s/%s",dirlist->path,entry->url);
+            ret = menuapp_display_image(dirlist,sel,0);
 
-#ifdef HAVE_MAGICK
-            if ( ( surface = surface_alloc(w,d,24) ) != NULL ) {
-                if ( mvp_image_display(surface,buf,-1,-1,w,d) == 0 ) {
-#else
-             if ( filetype == (MEDIA_JPEG|MEDIA_PICTURE) && 
-                  ( surface = surface_alloc(w,d,24) ) != NULL ) {
-                if ( mvp_jpeg_display(surface,buf,-1,-1,w,d) == 0 ) {
-#endif
-                    dirlist->menuapp->old_sfc = render_attach_surface(dirlist->menuapp->render,surface);
-                    if ( dirlist->menuapp->current_media == NULL ) {
-                        program_register_keys(dirlist->menuapp->program,REGISTER_MEDIA,media_keys,dirlist->menuapp);
-                    } 
+            printf("Dirlist is %p menu %p\n",dirlist,menu);
 
-                    return 1;
-                }
-                surface_dealloc(surface);
+            if ( ret == 1 ) {
+                program_register_keys(dirlist->menuapp->program,REGISTER_MEDIA,media_keys,dirlist->menuapp);
             }
+
+            return ret;
 #endif
         } else if ( filetype == 0 ) {   /* Try and grok a placelist */
             if ( playlist_parse(dirlist->menuapp,dirlist->path,entry->url) == 0 ) {
@@ -978,11 +969,28 @@ static int media_keys(void *ptr, int code)
 
     }
     /* If we've got an old_sfc then we're viewing a picture */
+#if HAVE_LIBJPEG | HAVE_MAGICK
     if ( menuapp->old_sfc ) {
+        /* Get the dirlist, this horribly breaks scope but if we're viewing
+           a picture then we can't have changed menus
+        */
+        menu_t       *menu = menuapp->menu;
+        menu_t       *child;
+        dirlist_t    *dirlist;
+
+        /* We have to find the bottom menu */
+        while ( ( child = menu_child(menu) ) ) {
+                menu = child;
+        }
+
+        dirlist = (dirlist_t *)menu_return_param(menu);
+
+        printf("Dirlist2 is %p %p\n",dirlist,menu);
+
+
         switch ( code ) {
         case keyMenu:
         case keyBack:
-        case keyOk:
             sfc = render_attach_surface(menuapp->render,menuapp->old_sfc);
             menuapp->old_sfc = NULL;
             surface_dealloc(sfc);
@@ -990,10 +998,48 @@ static int media_keys(void *ptr, int code)
                 program_register_keys(menuapp->program,REGISTER_MEDIA,NULL,menuapp);
             }
             break;
+        case keyOk:
+        case keyPlay:
+        case keyChanDn:
+        case keySkip:
+        case keyFastFwd:
+        {
+            int    sel = dirlist->currentsel;
+            if ( sel < ( dirlist->filelist_num-1) ) {
+                dirlist->currentsel++;
+                menu_set_entry(menu,menu_get_entry(menu) +1 );
+            }
+            menuapp_display_image(dirlist,dirlist->currentsel,0);
+            break;
+        }
+        case keyFastRew:
+        case keyChanUp:
+        case keyReplay:
+        {
+            int    sel = dirlist->currentsel;
+            if ( sel > 0  ) {
+                dirlist->currentsel--;
+                menu_set_entry(menu,menu_get_entry(menu) +1 );
+            }
+            menuapp_display_image(dirlist,dirlist->currentsel,0);
+            break;
+        }
+        case keyGreen:
+            menuapp_display_image(dirlist,dirlist->currentsel,90);
+            break;
+        case keyRed:
+            menuapp_display_image(dirlist,dirlist->currentsel,180);
+            break;
+        case keyYellow:
+            menuapp_display_image(dirlist,dirlist->currentsel,270);
+            break;
+        case keyBlue:
+            menuapp_display_image(dirlist,dirlist->currentsel,0);
+            break;
         }
-
         return 1;
     }
+#endif
 
 
     /* If it's the plugin, some keys have different behaviour */
@@ -1179,6 +1225,7 @@ static dirlist_t    *new_dirlist(menuapp_t *menuapp)
     dir->menuapp = menuapp;
     dir->title = NULL;
     dir->path = NULL;
+    dir->currentsel = 0;
     return dir;
 }
 
@@ -1187,6 +1234,8 @@ static void          delete_dirlist(void *idir)
     dirlist_t *dir = (dirlist_t *)idir;
     int        i;
 
+    printf("Deleting dirlist at %p\n",dir);
+
     for ( i = 0; i < dir->filelist_num; i++ ) {
         free(dir->filelist[i].display_name);
         free(dir->filelist[i].url);
@@ -1743,6 +1792,61 @@ static int dial_entry(menu_t *menu, void *imenuapp, int key, int sel)
 }
 
 
+/** \brief Display an image
+ *
+ *  \param dirlist
+ *  \param idx
+ *  \param rotate
+ *
+ *  \retval 1
+ *  \retval 0
+ */
+#if HAVE_MAGICK | HAVE_LIBJPEG
+static int menuapp_display_image(dirlist_t *dirlist, int index, int rotate)
+{
+    char         buf[FILENAME_MAX+1];
+    int          filetype = 0;
+    filelist_t  *entry = &dirlist->filelist[index];
+
+    snprintf(buf,sizeof(buf),"%s/%s",dirlist->path,entry->url);
+    filetype = file_get_type(buf); 
+
+    if ( filetype & MEDIA_PICTURE ) {
+        surface_t  *surface;
+        surface_t  *old_sfc;
+        int         w,d;
+        
+        w = render_get_width(dirlist->menuapp->render);
+        d = render_get_depth(dirlist->menuapp->render);
+        snprintf(buf,sizeof(buf),"%s/%s",dirlist->path,entry->url);
+
+        if ( ( surface = surface_alloc(w,d,24) ) != NULL ) {
+#ifdef HAVE_MAGICK
+            if ( mvp_image_display(surface,buf,-1,-1,w,d,rotate,SCALE_DOWN) == 0 )
+#else
+                if ( mvp_jpeg_display(surface,buf,-1,-1,w,d) == 0 )
+#endif
+                {
+                    //save old surface if this was the menu
+                    if (dirlist->menuapp->old_sfc == NULL) {
+                        dirlist->menuapp->old_sfc = render_attach_surface(dirlist->menuapp->render,surface);
+                    } else {
+                        old_sfc = render_attach_surface(dirlist->menuapp->render,surface);
+                        surface_dealloc(old_sfc);
+                    }
+
+                    return 1;
+                }
+            surface_dealloc(surface);
+        } 
+    } else {
+        return 0;
+    }
+    return 1; 
+}
+#endif
+
+
 
 /*
  * Local Variables:
