@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: menuapp.h,v 1.6 2004/04/22 18:36:24 dom Exp $
- *   $Date: 2004/04/22 18:36:24 $
+ *   $Id: menuapp.h,v 1.7 2005/03/31 10:45:58 dom Exp $
+ *   $Date: 2005/03/31 10:45:58 $
  *
  *
  *   Details of the menuapp
@@ -83,6 +83,9 @@ extern int             menu_get_dialcode_selection(menu_t *menu);
 extern void            menu_set_dialcode_selection(menu_t *menu, int sel);
 extern menu_t         *menu_parent(menu_t *menu);
 extern menu_t         *menu_child(menu_t *menu);
+extern void           *menu_return_param(menu_t *menu);
+extern void            menu_set_entry(menu_t * menu, int entry);
+extern int             menu_get_entry(menu_t *menu);
 
 
 #endif
