@@ -1,8 +1,8 @@
 /*
  *  MediaMVP Output Device for VDR
  *
- *  $Id: mvpprog.c,v 1.2 2004/05/22 16:41:27 dom Exp $ 
- *  $Date: 2004/05/22 16:41:27 $
+ *  $Id: mvpprog.c,v 1.4 2004/05/27 19:05:44 dom Exp $ 
+ *  $Date: 2004/05/27 19:05:44 $
  *
  *  The MVP application
  *
@@ -49,9 +49,6 @@ cMvpProgram::cMvpProgram()
     /* Set up the event loop */
     event_init();
 
-    /* Add up a reading event for sending events about the place */
-    event_set(&event,pipes[0],EV_READ,EventProcess_cb,(void *)this);
-    event_add(&event,NULL);
 
     /* Set up some parameters */
     Running = false;
@@ -61,6 +58,12 @@ cMvpProgram::cMvpProgram()
     MediamvpSetup.authorise = Authorise;
 
     mediamvp_server_init(&MediamvpSetup);
+
+
+    /* Add up a reading event for sending events about the place */
+    event_set(&event,pipes[0],EV_READ,EventProcess_cb,(void *)this);
+    event_add(&event,NULL);
+
     surface = surface_alloc(c_gui_width,c_gui_depth,8);
     surface_clear(surface,0);
     surface_set_pixel(surface,100,100,0x00FFFFFF);
@@ -75,12 +78,18 @@ cMvpProgram::cMvpProgram()
 
 cMvpProgram::~cMvpProgram()
 {
+    delete url;
+    delete ringy;
     surface_dealloc(surface);
+    Cancel(3);
 }
 
 void cMvpProgram::Connect(dongle_t *dgl)
 {
     dongle = dgl;
+    /* Set up some parameters */
+    Running = false;
+    display = false;
 }
 
 void cMvpProgram::Disconnect()
@@ -104,9 +113,8 @@ int cMvpProgram::PlayVideo(const uchar *Data, int Length)
 uint8_t  *cMvpProgram::Surface(int *size)
 {
     if ( surface_get_dirty(surface)  ) {
-        *size = surface_get_yuvsize(surface);
         surface_set_dirty(surface,FALSE);
-        return (uint8_t *) surface_rgb2yvuy(surface);
+        return (uint8_t *) surface_map(surface,MAP_YVU,size);
     }
   
     return NULL;
@@ -165,32 +173,6 @@ bool cMvpProgram::Poll(cPoller &Poller, int TimeoutMs)
 void cMvpProgram::SendEvent(mvpevent_t event)
 {
     /* Fix the pipe, this is probably called on the wrong thread... */
-    printf("Sending event %d %d\n",event,sizeof(mvpevent_t));
-    if ( dongle != NULL ) {
-        switch ( event ) {
-        case MEVT_STOP:
-        case MEVT_PLAY:
-        case MEVT_PAUSE:
-        case MEVT_MUTE:
-            break;
-        case MEVT_MENU_ON:
-            if (display == false ) 
-                dongle_send_message(dongle,RDC_DISPLAY_ON);
-            display = true;
-            break;
-        case MEVT_MENU_OFF:
-            if ( display == true )
-                dongle_send_message(dongle,RDC_DISPLAY_OFF);
-            display = false;
-            break;
-        case MEVT_UPDATE:
-            if ( display )
-                dongle_update_screen(dongle);
-            break;      
-        }
-
-    }
-
     safe_write(pipes[1],&event,sizeof(mvpevent_t));
 }
 
@@ -211,9 +193,7 @@ static void  EventProcess_cb(int fd, short event, void *arg)
     mvpevent_t   c;
     event_add(&Instance->event,NULL);
 
-    printf("Read event\n");
     read(fd,&c,sizeof(c));
-    printf("Received event %d\n",c);
 
     if ( Instance->dongle ) {
         switch ( c ) {
@@ -229,7 +209,7 @@ static void  EventProcess_cb(int fd, short event, void *arg)
             break;
         case MEVT_MENU_OFF:
             if ( Instance->display == true )
-                dongle_send_message(Instance->dongle,RDC_DISPLAY_ON);
+                dongle_send_message(Instance->dongle,RDC_DISPLAY_OFF);
             Instance->display = false;
             break;
         case MEVT_UPDATE:
