@@ -1,8 +1,8 @@
 /*
  *  MediaMVP Output Device for VDR
  *
- *  $Id: mvpwrap.c,v 1.1 2004/04/25 16:35:46 dom Exp $ 
- *  $Date: 2004/04/25 16:35:46 $
+ *  $Id: mvpwrap.c,v 1.2 2004/05/22 16:41:27 dom Exp $ 
+ *  $Date: 2004/05/22 16:41:27 $
  *
  *  This wraps up the real device in a redirecting layer
  *
@@ -26,7 +26,9 @@ cMvpWrap::~cMvpWrap()
 
 void cMvpWrap::MakePrimaryDevice(bool On)
 {
-
+#if VDRVERSNUM >= 10307
+    Program.NewOsdProvider();
+#endif
 }
 
 int cMvpWrap::ProvidesCa(int Ca)
@@ -106,8 +108,9 @@ bool cMvpWrap::Poll(cPoller &Poller, int TimeoutMs)
     return true;
 }
 
-
+#if VDRVERSNUM < 10307
 cOsdBase *cMvpWrap::NewOsd(int x, int y)
 {
     return Program.NewOsd(x,y);
 }
+#endif
