@@ -3,7 +3,7 @@
  *
  * See the README file for copyright information and how to reach the author.
  *
- * $Id: i18n.c,v 1.10 2004/10/17 20:57:06 dom Exp $
+ * $Id: i18n.c,v 1.13 2005/02/01 21:15:12 dom Exp $
  */
 
 #include "i18n.h"
@@ -31,6 +31,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "MediaMVP GUI Port",            // English
@@ -55,6 +58,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "MediaMVP Stream Port",         // English
@@ -79,6 +85,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
    { "MediaMVP dongle.bin version",   // English
@@ -103,6 +112,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
    { "Total Screen Width",            // English
@@ -127,6 +139,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
    { "Total Screen Depth",            // English
@@ -151,6 +166,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
    { "GUI Screen Width",              // English
@@ -175,6 +193,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
    { "GUI Screen Depth",              // English
@@ -199,6 +220,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "MediaMVP",                     // English
@@ -223,6 +247,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Channels",                     // English
@@ -247,6 +274,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Internet Radio",               // English
@@ -271,6 +301,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Other Videos",                 // English
@@ -295,6 +328,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Music",                        // English
@@ -319,6 +355,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Settings",                     // English
@@ -343,6 +382,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "NTSC",                         // English
@@ -367,6 +409,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "PAL",                          // English
@@ -391,6 +436,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "None",                         // English
@@ -415,6 +463,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
    { "Low",                           // English
@@ -439,6 +490,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
    { "Medium",                        // English
@@ -463,6 +517,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "High",                         // English
@@ -487,6 +544,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "RGB Detected",                 // English
@@ -511,6 +571,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "SVideo",                       // English
@@ -535,6 +598,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Composite",                    // English
@@ -559,6 +625,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "RGB/Composite",                // English
@@ -583,6 +652,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "TV Mode:",                     // English
@@ -607,6 +679,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Output:",                      // English
@@ -631,6 +706,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Flicker Control:",             // English
@@ -655,6 +733,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Aspect Ratio:",                // English
@@ -679,6 +760,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Cancel changes",               // English
@@ -703,6 +787,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Save settings (may take a while)",  // English
@@ -727,6 +814,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Play list",                    // English
@@ -751,6 +841,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Play dir",                     // English
@@ -775,6 +868,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Debug Level",                  // English
@@ -799,6 +895,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Pictures",                     // English
@@ -823,6 +922,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "News Feeds",                   // English
@@ -847,6 +949,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { "Screensaver Enabled",          // English
@@ -871,10 +976,13 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
    { "Switch standards",              // English
-      "",                             // Deutsch
+      "TV Norm Wechseln",             // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -895,6 +1003,9 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10313
       "",                             // Croatian
       "",                             // Estonian
+#endif
+#if VERVERSNUM >= 10316
+      "",                             // Danish
 #endif
     },
     { NULL }
