@@ -4,8 +4,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: menuapp-vdr.c,v 1.9 2004/10/15 11:46:48 dom Exp $
- *   $Date: 2004/10/15 11:46:48 $
+ *   $Id: menuapp-vdr.c,v 1.17 2005/04/01 11:39:19 dom Exp $
+ *   $Date: 2005/04/01 11:39:19 $
  *
  *
  *   Contains vdr specific functionality for the menuapp
@@ -60,7 +60,11 @@ static int menuapp_channels(menu_t *menu,void *imenuapp, int sel)
 
         } else {
             snprintf(buf,sizeof(buf),"% 3d %s",chan->Number(),chan->Name());
+#if VDRVERSNUM >= 10318
+            snprintf(buf2,sizeof(buf2),"%s%s",VDRURL,*chan->GetChannelID().ToString());
+#else
             snprintf(buf2,sizeof(buf2),"%s%s",VDRURL,chan->GetChannelID().ToString());
+#endif
             /* Make the dial code the channel number */
             snprintf(buf3,sizeof(buf3),"%d",chan->Number());
             list = filelist_add(list,&list_num,buf,buf2,strdup(buf3),FILE_URL);
@@ -148,9 +152,14 @@ static int schedule_menuapp(menu_t *menu, void *imenuapp, int sel)
                     char       buf[1024];
                     char       buf2[1024];
                     char       buf3[20];
+#if VDRVERSNUM >= 10318
+                    snprintf(buf,sizeof(buf),"%d\t%.*s\t%.*s\t%s", Channel->Number(), 6, Channel->Name(), 5, *Event->GetTimeString(), Event->Title());
+                    snprintf(buf2,sizeof(buf2),"%s%s",VDRURL, *Channel->GetChannelID().ToString());
+#else
                     snprintf(buf,sizeof(buf),"%d\t%.*s\t%.*s\t%s", Channel->Number(), 6, Channel->Name(), 5, Event->GetTimeString(), Event->Title());
-    
                     snprintf(buf2,sizeof(buf2),"%s%s",VDRURL, Channel->GetChannelID().ToString());
+#endif
+    
 
                     snprintf(buf3,sizeof(buf3),"%d",Channel->Number());
 
@@ -171,6 +180,8 @@ static int schedule_menuapp(menu_t *menu, void *imenuapp, int sel)
 
     menu_set_colour_actions(child,tr("Back") /* tr("Record") */, menuapp->Now ? tr("Next") : tr("Now"), NULL /* tr("Schedule") */, tr("Switch"),schedule_colour_keys);
 
+    menu_set_entry(child,menuapp->current_position);
+
     menu_display(child);
 
     return 1;
@@ -289,6 +300,7 @@ static int schedule_menuapp(menu_t *menu, void *imenuapp, int sel)
 
     menu_set_colour_actions(child,tr("Back") /* tr("Record") */, menuapp->Now ? tr("Next") : tr("Now"), NULL /* tr("Schedule") */, tr("Switch"),schedule_colour_keys);
 
+    menu_set_entry(menuapp->current_position);
     menu_display(child);
 
     return 1;
@@ -305,10 +317,12 @@ static int schedule_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
 
     switch ( key ) {
     case keyRed:
+        menuapp->current_position = 0;
         return 0 ;
     case keyGreen:
         menuapp->Now ^= 1;
         parent = menu_parent(menu);
+        menuapp->current_position = menu_get_entry(menu);
         schedule_menuapp(parent,menuapp,0);
         return 0;
     case keyYellow:
@@ -463,8 +477,7 @@ static filelist_t *recordings_scan(char *base, int level, int *num)
                     snprintf(buf,sizeof(buf),"%s",recording->Title(' ',true,level));
                     snprintf(buf2,sizeof(buf2),"%s%s",VDRRECURL,recording->Title(' ',true));
                     list = filelist_add(list,num,buf,buf2,NULL,FILE_URL);
-                } else if ( lev == tlevel + 1 ) {  /* At one level down from where we're browsing */
-                    
+                } else if ( lev >= tlevel + 1 ) {  /* At one level down from where we're browsing */
                     /* Same path as last time, add it into the list */
                     if ( lastitem && strcmp(buf,lastitem) == 0 ) {
                         lastcount++;
@@ -545,7 +558,7 @@ int  media_keys_vdr(menuapp_t *menuapp,int code)
         if (  ( (streamtype & (MEDIA_LIVE | MEDIA_MPEG) ) == (MEDIA_LIVE | MEDIA_MPEG) ) ) {
             if ( menuapp->current_media && strncmp(menuapp->current_media,VDRURL,strlen(VDRURL)) == 0  ) {
                 char           buf[2048];
-                const char    *newchannel = ChannelSkip(menuapp->current_media + strlen(VDRURL),
+                char    *newchannel = ChannelSkip(menuapp->current_media + strlen(VDRURL),
                                                         code == keyChanUp ? 1 : -1 );
                 if ( newchannel ) {
                     if ( menuapp->current_media ) {        
@@ -553,8 +566,11 @@ int  media_keys_vdr(menuapp_t *menuapp,int code)
 		    }
                     snprintf(buf,sizeof(buf),"%s%s",VDRURL,newchannel);
                     menuapp->current_media = strdup(buf);
+                    free(newchannel);
                     menuapp->paused = FALSE;
+#ifdef CAM_CHANGE_HACK
 		    dongle_send_message(menuapp->dongle,RDC_STOP);
+#endif
                     dongle_send_play(menuapp->dongle,buf);
                 }
             }
@@ -617,20 +633,46 @@ static filelist_t *plugin_file_scan(char *filename, int *scanned)
     return list;    
 }
 
-static cRecording* find_recording(const char *dirname) {
+static bool_t find_recording(const char *dirname) {
     char          dirpath[PATH_MAX];
     char          recpath[PATH_MAX];
 
+#if VDRVERSNUM < 10312
+    cRecordings   Recordings;
+    Recordings.Load();
+#endif
+
     if (realpath(dirname,dirpath)) { /* recording does exist */
+        
         for (cRecording *recording = Recordings.First(); recording; recording = Recordings.Next(recording)) {
             /* search for recordings comparing real paths */
             if (realpath( recording->FileName(), recpath ) && strcmp(dirpath, recpath) == 0) {
-                return recording;
+                return TRUE;
             }
         }
     }
 
-    return NULL;
+    return FALSE;
+}
+
+static void delete_recording(const char *dirname) {
+    char          dirpath[PATH_MAX];
+    char          recpath[PATH_MAX];
+    
+#if VDRVERSNUM < 10312
+    cRecordings   Recordings;    
+    Recordings.Load();
+#endif
+
+    if (realpath(dirname,dirpath)) { /* recording does exist */
+        
+        for (cRecording *recording = Recordings.First(); recording; recording = Recordings.Next(recording)) {
+            /* search for recordings comparing real paths */
+            if (realpath( recording->FileName(), recpath ) && strcmp(dirpath, recpath) == 0) {
+            	recording->Delete();
+            }
+        }
+    }
 }
 
 
@@ -649,7 +691,6 @@ static int is_vdr_recording(const char *dirname) {
 static int recdel_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
 {
     dirlist_t     *dir = (dirlist_t *)imenuapp;
-    cRecording    *recording;
     menu_t        *p_menu;
     menu_t        *pp_menu;
     menu_t        *ppp_menu;
@@ -658,9 +699,7 @@ static int recdel_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
     case keyRed:
         return 0;
     case keyGreen:       /* Really delete the recording */
-        recording = find_recording(dir->path);
-        if (recording) {
-            recording->Delete();
+	delete_recording(dir->path);
 
             /* Delete this menu, it's parent, and it's parent's parent */
             p_menu = menu_parent(menu);
@@ -672,9 +711,6 @@ static int recdel_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
 
             menu_display(ppp_menu);
             return 1; /* important, menu is invalid now */
-        }
-
-        break;
     default:
         break;
     }
@@ -683,3 +719,4 @@ static int recdel_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
 }
 
 
+
