@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: misc.h,v 1.3 2004/04/19 20:22:30 dom Exp $
- *   $Date: 2004/04/19 20:22:30 $
+ *   $Id: misc.h,v 1.4 2005/03/31 10:45:57 dom Exp $
+ *   $Date: 2005/03/31 10:45:57 $
  *
  *   Misc stuff, stolen from streamdev
  */
@@ -18,7 +18,7 @@
 #include <ctype.h>
 
 extern cChannel      *ChannelFromString(char *String);
-extern const char    *ChannelSkip(char *String, int direction);
+extern char          *ChannelSkip(char *String, int direction);
 
 #endif
 
