@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: gui.c,v 1.25 2004/05/07 22:50:13 dom Exp $
- *   $Date: 2004/05/07 22:50:13 $
+ *   $Id: gui.c,v 1.26 2004/09/16 19:37:04 dom Exp $
+ *   $Date: 2004/09/16 19:37:04 $
  *
  *
  *   Handles the GUI...
@@ -20,6 +20,7 @@
 struct _gui {
     application_t  application;      /* Controlling application spec */
     dongle_t      *dongle;
+    mutex_t        mutex;
     struct event   event;
     int            fd;
     int            state;
@@ -133,7 +134,7 @@ static gui_t *new_gui(dongle_t *dongle)
     gui->inbufstart = 0;
     gui->send_update = TRUE;
 
-  
+    mutex_init(&gui->mutex,NULL);
    
     return gui;
 }
@@ -144,6 +145,8 @@ void delete_gui(gui_t *gui)
     close(gui->fd);
     shutdown(gui->fd,SHUT_RDWR);
     gui->application.close(&gui->application);
+
+    mutex_destroy(&gui->mutex);
     free(gui);
 }
 
@@ -456,17 +459,22 @@ static void rfb_send_data(gui_t *gui)
     unsigned char *ptr;
     int   len;
 
+
     switch ( gui->state ) {
     case VNC_VERSION:
         len = sprintf((char*)buf,"RFB %03d.%03d\012",RFB_MAJOR,RFB_MINOR);
+        mutex_lock(&gui->mutex);
         write(gui->fd,buf,len);
+        mutex_unlock(&gui->mutex);
         break;
     case VNC_AUTH:
         buf[0] = 0;
         buf[1] = 0;
         buf[2] = 0;
         buf[3] = RFB_AUTH_NONE;
+        mutex_lock(&gui->mutex);
         write(gui->fd,buf,4);
+        mutex_unlock(&gui->mutex);
         break;
     case VNC_INIT:
         ptr = buf;
@@ -489,7 +497,9 @@ static void rfb_send_data(gui_t *gui)
         INT32_TO_BUF(len,ptr);
         strcpy((char*)ptr,"rfbwindows");
         ptr += len;
+        mutex_lock(&gui->mutex);
         write(gui->fd,buf,ptr - buf);
+        mutex_unlock(&gui->mutex);
         gui_send_settings(gui,RDC_SETTINGS_GET);
         gui->state = VNC_RUNNING;
         break;
@@ -542,8 +552,10 @@ static void rfb_send_screen(gui_t *gui)
     INT16_TO_BUF(0,ptr);        /* colour format, 0 = yuv */
     INT16_TO_BUF(2,ptr);        /* bytes per pixel */
 
+    mutex_lock(&gui->mutex);
     write(gui->fd,buf,ptr - buf);
     write(gui->fd,comp,gz);
+    mutex_unlock(&gui->mutex);
 
     free(comp);
     free(surface);
@@ -637,7 +649,9 @@ void gui_send_play(gui_t *gui, char *name)
 
     strcpy((char*)(buf + msg->len),name);
 
+    mutex_lock(&gui->mutex);
     write(gui->fd,buf,len + msg->len);
+    mutex_unlock(&gui->mutex);
 }
 
 /** \internal
@@ -662,11 +676,14 @@ void gui_send_message(gui_t *gui, int msgtype)
 
     msg = msglist[msgtype];
 
+    mutex_lock(&gui->mutex);
     write(gui->fd,msg->msg,msg->len);
+    mutex_unlock(&gui->mutex);
 }
 
 void gui_send_percent(gui_t *gui, int msgtype, int percent)
 {
+    unsigned char buf[256];
     mvprfbmsg_t **msglist;
     mvprfbmsg_t  *msg;
 
@@ -680,9 +697,13 @@ void gui_send_percent(gui_t *gui, int msgtype, int percent)
 
     msg = msglist[msgtype];
 
-    msg->msg[19] = percent; // bad - modifies message directly
+    memcpy(buf,msg->msg,msg->len);
 
-    write(gui->fd,msg->msg,msg->len);
+    buf[19] = percent;
+
+    mutex_lock(&gui->mutex);
+    write(gui->fd,buf,msg->len);
+    mutex_unlock(&gui->mutex);
 }
 
 
@@ -693,18 +714,30 @@ void gui_send_percent(gui_t *gui, int msgtype, int percent)
  */
 void gui_send_settings(gui_t *gui, int subcommand)
 {
-    char    buf[12];
+    unsigned char    buf[256];
+    mvprfbmsg_t     *msg;
+    int              len;
 
-    gui_send_message(gui,RDC_SETTINGS);
+    if ( initparams->dongle_version < 21365 ) {
+        msg = &rfb_media_settings;
+    } else {
+        msg = &rfb_media_settings_22012;
+    }
 
-    buf[0] = subcommand;
-    buf[1] = gui->dongle->tvmode;
-    buf[2] = gui->dongle->videooutput;
-    buf[3] = gui->dongle->flickermode;
-    buf[4] = gui->dongle->aspectratio;
-    buf[5] = buf[6] = buf[7] = buf[8] = buf[9] = buf[10] = buf[11] = 0;
+    len = msg->len;
+    memcpy(buf,msg->msg,len);
 
-    write(gui->fd,buf,12);
+    buf[len + 0] = subcommand;
+    buf[len + 1] = gui->dongle->tvmode;
+    buf[len + 2] = gui->dongle->videooutput;
+    buf[len + 3] = gui->dongle->flickermode;
+    buf[len + 4] = gui->dongle->aspectratio;
+    buf[len + 5] = buf[len + 6] = buf[len + 7] = 0;
+    buf[len + 8] = buf[len + 9] = buf[len + 10] = buf[len + 11] = 0;
+
+    mutex_lock(&gui->mutex);
+    write(gui->fd,buf,len + 12);
+    mutex_unlock(&gui->mutex);
 }
 
 
