@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: url_file.c,v 1.10 2004/10/24 11:37:37 dom Exp $
- *   $Date: 2004/10/24 11:37:37 $
+ *   $Id: url_file.c,v 1.12 2004/11/13 10:56:52 dom Exp $
+ *   $Date: 2004/11/13 10:56:52 $
  *
  *
  *   Deals with opening a file and fobbing off playlist detection
@@ -181,41 +181,101 @@ static int file_info(void *ptr, int cmd, void *dest)
 
 static int file_gop_seek(file_t *file, gopseek_t *gop)
 {
-    unsigned char    buf[1024];
+    unsigned char    buf[131072]; // should be enough space for 2 GOPs --> less I/O
     int     count =  1;
     int     offset = 0;
     int     i,r;
-    bool_t  seekstart = TRUE;
-    int     stepsize;
+    int     seekmode;
+    bool_t  backward;
+
+   /*
+     It should work the following way:
+
+     When seeking backwards, first seek back two pictures. This avoids hanging at one picture,
+     which may happen when identifing data as a GOP/sequence header, which sometimes happens (seekmode == -1).
+
+     Then, seek given count of GOP headers forward / backward (seekmode == 0).
+     
+     Then, seek backwards for sequence start code (seekmode == 1),
+     then backwards to system start code (seekmode == 2), which is gop->start
+     
+     Then, seek start of picture after I-frame picture (seekmode == 3) for gop->length
+    */
+
 
     offset = lseek(file->fd,0,SEEK_CUR);
 
+    Dprintf(DEBUG,"Seeking %d GOPs @ 0x%08x\n", gop->count, offset);
+
     if ( gop->count < 0 ) {
-        stepsize = -sizeof(buf);
-        count = -gop->count;
+        /* Search backward two pictures, avoids hanging */
+        backward = TRUE;
+        count = 2;
+        seekmode = -1;
     } else {
-        stepsize = sizeof(buf);
+    	/* search forward N GOP headers */
+        backward = FALSE;
         count = gop->count;
+        seekmode = 0;
+    }
+
+    if (backward) {
+        offset -= sizeof(buf);
+        if (offset < 0) {
+	    offset = 0;
+        }
     }
 
     while ( count > 0 && offset >= 0 ) {
         lseek(file->fd,offset,SEEK_SET);
         r = read(file->fd,buf,sizeof(buf));
-        if ( r <= 0 )
+        if ( r <= 0 ) {
             break;
+        }
             
-        for ( i = 0; i < r - 3 ; i++ ) {
-            if ( seekstart == TRUE ) {
-                /* Seek sequence start code - this will contain an iframe */
-                if ( buf[i] == 0x00 && buf[i+1] == 0x00 && buf[i+2] == 0x01 && buf[i+3] == 0xb3 ) {
+        for ( i = (backward ? r - 4 : 0); count && (backward ? i >= 0 : i < r - 3) ; (backward ? i-- : i++) ) {
+            if ( seekmode == -1 ) {
+                if ( buf[i] == 0x00 && buf[i+1] == 0x00 && buf[i+2] == 0x01 && buf[i+3] == 0x00 ) {
+	            /* Search backward two pictures, avoids hanging */
                     if ( --count == 0 ) {
-                        gop->start = offset + i;
-                        count = 2; /* We need the second picture header */
-                        seekstart = FALSE;
-                        stepsize = sizeof(buf);
+                    	/* search backward N GOP headers */
+		        backward = TRUE;
+		        count = -gop->count;
+                    	seekmode = 0;
                     }                            
                 }
-            } else {
+            } else if ( seekmode == 0 ) {
+                /* Seek GOP code - this will contain an iframe */
+                if ( buf[i] == 0x00 && buf[i+1] == 0x00 && buf[i+2] == 0x01 && buf[i+3] == 0xb8 ) {
+                    if ( --count == 0 ) {
+                    	/* search backward one sequence header */
+		        backward = TRUE;
+                    	count = 1;
+                    	seekmode = 1;
+                    }            
+                }
+            } else if ( seekmode == 1 ) {
+                /* Seek sequence start code */
+                if ( buf[i] == 0x00 && buf[i+1] == 0x00 && buf[i+2] == 0x01 && buf[i+3] == 0xb3 ) {
+                    if ( --count == 0 ) {
+                    	/* search backward elementary stream header */
+		        backward = TRUE;
+		        count = 1;
+		        seekmode = 2;
+                    }                            
+                }
+            } else if (seekmode == 2) {
+                /* System code for video elementary stream */
+                if ( buf[i] == 0x00 && buf[i+1] == 0x00 && buf[i+2] == 0x01 && buf[i+3] == 0xe0 ) {
+                    if ( --count == 0 ) {
+                    	/* search picture after i-frame picture for end of I-frame */
+                        gop->start = offset + i;
+		        backward = FALSE;
+		        count = 2;
+		        seekmode = 3;
+                    }                            
+                }
+            } else if (seekmode == 3) {
                 /* Seek a picture header */
                 if ( buf[i] == 0x00 && buf[i+1] == 0x00 && buf[i+2] == 0x01 && buf[i+3] == 0x00 ) {
                     if ( --count == 0 ) {
@@ -225,20 +285,22 @@ static int file_gop_seek(file_t *file, gopseek_t *gop)
             }
         }    
         if ( count != 0 ) {
-            if ( stepsize < 0 ) {
-                offset -= sizeof(buf);
+            if ( backward ) {
+                offset -= sizeof(buf) - 3; // we may have missed header at start of buf !
             } else {
-                offset += r;
+                offset += r - 3; // we may have missed header at end of buf !
             }
-            /* If we go back to far, just go the start of the file and try again (going forwards) */
+            /* If we go back to far, GOP is at start of file */
             if ( offset < 0 ) {
-                count = 1;
-                offset = 0;
-                stepsize = sizeof(buf);
+               gop->start = 0;
+	       backward = FALSE;
+	       count = 2;
+	       seekmode = 3;
             }
         }
     }
     
+    Dprintf(DEBUG,"Found GOP %d @ 0x%08x\n", gop->length, gop->start);
 
     if ( count != 0 ) {
         return -1;
