@@ -8,6 +8,13 @@
 
 #define PROTECTIONSIZE 32768
 
+#ifndef RESULTBUFFERSIZE
+#define RESULTBUFFERSIZE KILOBYTE(256)
+#endif
+#ifndef MINVIDEODATA
+#define MINVIDEODATA (16*1024)
+#endif
+
 class cTSRemux {
 protected:
   uchar m_PROTECTION1[PROTECTIONSIZE]; // something sometimes overwrites vtbl without this buffer
