@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: transceiver.c,v 1.6 2004/03/16 20:07:04 dom Exp $
- *   $Date: 2004/03/16 20:07:04 $
+ *   $Id: transceiver.c,v 1.8 2005/02/06 14:18:42 dom Exp $
+ *   $Date: 2005/02/06 14:18:42 $
  *
  *   Transceiver stuff - blatantly stolen from streamdev then changed
  *   a bit..
@@ -35,9 +35,17 @@
 #define BUFOVERCOUNT 100
 
 cMediamvpTransceiver::cMediamvpTransceiver(const cChannel *Channel, int Priority, int Socket, cDevice *Device) :
+#if VDRVERSNUM >= 10319
+		cReceiver(Channel->Ca(), Priority, Channel->Vpid(), Channel->Apids(), Channel->Dpids(), Channel->Spids()) {
+#else
                 cReceiver(Channel->Ca(), Priority, 7, Channel->Vpid(), Channel->Ppid(),
+#if VDRVERSNUM >= 10318
+                                Channel->Apid(0), Channel->Apid(1), Channel->Dpid(0), Channel->Dpid(1), 
+#else
                                 Channel->Apid1(), Channel->Apid2(), Channel->Dpid1(), Channel->Dpid2(), 
+#endif
                                 Channel->Tpid()) {
+#endif
         m_Active = false;
         m_Socket = Socket;
         m_Remux = NULL;
@@ -47,9 +55,17 @@ cMediamvpTransceiver::cMediamvpTransceiver(const cChannel *Channel, int Priority
 
     /* Select the correct Muxing depending on whether it's video or not */
     if ( Channel->Vpid() == 0 || Channel->Vpid() == 1 || Channel->Vpid() == 0x1FFF ) {
+#if VDRVERSNUM >= 10318
+        m_Remux = new cTS2ESRemux(Channel->Apid(0));
+#else
         m_Remux = new cTS2ESRemux(Channel->Apid1());
+#endif
     } else {
+#if VDRVERSNUM >= 10318
+                m_Remux = new cTS2PSRemux(Channel->Vpid(), Channel->Apid(0), 0, 0, 0, 0);
+#else
                 m_Remux = new cTS2PSRemux(Channel->Vpid(), Channel->Apid1(), 0, 0, 0, 0);
+#endif
     }
     Dprintf(MOO,"Created transceiver at %p, remux @%p ringbuffer %p\n",this,m_Remux,m_RingBuffer);
 
@@ -101,16 +117,21 @@ void cMediamvpTransceiver::Receive(uchar *Data, int Length)
         if (m_Active) {
                 int p = m_RingBuffer->Put(Data, Length);
                 if (p != Length) {
+#if VDRVERSNUM >= 10318
+			int now = int(cTimeMs::Now());
+#else
+			int now = time_ms();
+#endif
                         ++errcnt;
                         if (showerr) {
                                 if (firsterr == 0)
-                                        firsterr = time_ms();
-                                else if (firsterr + BUFOVERTIME > time_ms() && errcnt > BUFOVERCOUNT) {
+                                        firsterr = now;
+                                else if (firsterr + BUFOVERTIME > now&& errcnt > BUFOVERCOUNT) {
                                         esyslog("ERROR: too many buffer overflows, logging stopped");
                                         showerr = false;
-                                        firsterr = time_ms();
+                                        firsterr = now;
                                 }
-                        } else if (firsterr + BUFOVERTIME < time_ms()) {
+                        } else if (firsterr + BUFOVERTIME < now) {
                                 showerr = true;
                                 firsterr = 0;
                                 errcnt = 0;
@@ -119,7 +140,7 @@ void cMediamvpTransceiver::Receive(uchar *Data, int Length)
                         if (showerr)
                                 esyslog("ERROR: ring buffer overflow (%d bytes dropped)", Length - p);
                         else
-                                firsterr = time_ms();
+                                firsterr = now;
                 }
         }
 }
